@@ -46,7 +46,7 @@ class moesif_middleware:
         # below comment for setting moesif base_uri to a test server.
         if self.middleware_settings.get('LOCAL_DEBUG', False):
             Configuration.BASE_URI = self.get_configuration_uri(self.middleware_settings, 'BASE_URI', 'LOCAL_MOESIF_BASEURL')
-        Configuration.version = 'moesifdjango-python/2.0.4'
+        Configuration.version = 'moesifdjango-python/2.0.5'
         if settings.MOESIF_MIDDLEWARE.get('CAPTURE_OUTGOING_REQUESTS', False):
             try:
                 if self.DEBUG:
@@ -188,7 +188,10 @@ class moesif_middleware:
 
         # Add transaction id to response headers
         if transaction_id:
-            response._headers["x-moesif-transaction-id"] = ("X-Moesif-Transaction-Id", transaction_id)
+            try:
+                response._headers["x-moesif-transaction-id"] = ("X-Moesif-Transaction-Id", transaction_id)
+            except AttributeError:
+                response.headers["x-moesif-transaction-id"] = transaction_id
 
         # Parse Response headers
         rsp_headers = self.logger_helper.parse_response_headers(response, self.middleware_settings)
